@@ -153,7 +153,7 @@ format_sf = function(x, lonlat = FALSE) {
 
 #' Convert STATS19 data into ppp (spatstat) format.
 #'
-#' This function is a wrapper around \code{\link[spatstat]{ppp}} function and
+#' This function is a wrapper around the [spatstat.geom::ppp()] function and
 #' it is used to transform STATS19 data into a ppp format.
 #'
 #' @param data A STATS19 dataframe to be converted into ppp format.
@@ -163,26 +163,26 @@ format_sf = function(x, lonlat = FALSE) {
 #'   events occurring in a specific region of UK (see the examples of
 #'   \code{\link{get_stats19}}).
 #' @param ... Additional parameters that should be passed to
-#'   \code{\link[spatstat]{ppp}} function. Read the help page of that function
+#'   [spatstat.geom::ppp()] function. Read the help page of that function
 #'   for a detailed description of the available parameters.
 #'
 #' @return A ppp object.
 #' @seealso \code{\link{format_sf}} for an analogous function used to convert
-#'   data into sf format and \code{\link[spatstat]{ppp}} for the original
-#'   spatstat function.
+#'   data into sf format and [spatstat.geom::ppp()] for the original
+#'   spatstat.core function.
 #' @export
 #'
 #' @examples
-#' if (requireNamespace("spatstat", quietly = TRUE)) {
+#' if (requireNamespace("spatstat.core", quietly = TRUE)) {
 #'   x_ppp = format_ppp(accidents_sample)
-#'   spatstat::plot.ppp(spatstat::unmark(x_ppp))
+#'   x_ppp
 #' }
 #'
 
 format_ppp = function(data, window = NULL,  ...) {
-  # check that spatstat is installed
-  if (!requireNamespace("spatstat", quietly = TRUE)) {
-    stop("package spatstat required, please install it first")
+  # check that spatstat.core is installed
+  if (!requireNamespace("spatstat.core", quietly = TRUE)) {
+    stop("package spatstat.core required, please install it first")
   }
 
   # look for column names of coordinates
@@ -202,13 +202,13 @@ format_ppp = function(data, window = NULL,  ...) {
 
   # owin object for ppp. Default values represent an approximate bbox of UK
   if (is.null(window)) {
-    window = spatstat::owin(
+    window = spatstat.geom::owin(
       xrange = c(64950, 655391),
       yrange = c(10235, 1209512)
     )
   }
 
-  data_ppp = spatstat::ppp(
+  data_ppp = spatstat.geom::ppp(
     x = data[[coords[[1]]]],
     y = data[[coords[[2]]]],
     window = window,
